ojo.extension.throttle

An ojo extension for limiting immediate consecutive events for any one file. The motivation for adding this behavior is that often the filesystem will issue multiple consecutive events for one user-relevant event. Throttling enables responding to a meaningful event, ignoring the extraneous events.

An ojo extension for limiting immediate consecutive events for any one file.
The motivation for adding this behavior is that often the filesystem will
issue multiple consecutive events for one user-relevant event. Throttling
enables responding to a meaningful event, ignoring the extraneous events.
raw docstring

ojo.extension.track-appends

An ojo extension for tracking append versus non-append file modifications.

An ojo extension for tracking append versus non-append file modifications.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries